@@ -15,8 +15,6 @@
 -- limitations under the License.
 
 {% materialization incremental, adapter='materialize' %}
-   -- Todo@jldlaughlin: Fail in a useful way!
-
    -- TL;DR: dbt-materialize does not support incremental models, use materializedview
    -- models instead.
 
@@ -27,4 +25,15 @@
    -- in, Materialize only performs work on that new data. And, all this happens without
    -- extra configurations or scheduled refreshes.
    -- For more information, please visit: https://materialize.com/docs/
+    {{ exceptions.raise_compiler_error(
+        """
+        dbt-materialize does not support incremental models, because all views in
+        Materialize are natively maintained incrementally.
+
+        Use the `materializedview` custom materialization instead.
+
+        See: https://materialize.com/docs/overview/api-components/#materialized-views
+        See: https://docs.getdbt.com/reference/warehouse-profiles/materialize-profile#materializations
+        """
+    )}}
 {% endmaterialization %}
